/**
 * Color object
 *
 * @public
 */
export declare interface ColorObject {
    color: number;
    ratio?: number | undefined;
}

/**
 * Convert the angle value of a string to an angle value
 *
 * @param value - target value
 * @param unit - unit type
 *
 * @public
 */
export declare function convertToDegree(value: string, unit?: string): string;

/**
 * css node declaration type
 *
 * @public
 */
export declare interface CssDeclarationType {
    type: string;
    property: string;
    value: string | number;
}

/**
 * CSS node
 *
 * @public
 */
export declare interface CssNode {
    [key: string]: NeedToTyped;
}

/**
 * CSS AST type
 *
 * @public
 */
export declare interface CssNodeType {
    type: string;
    selectors: string[];
    declarations: CssDeclarationType[];
}

/**
 * parse css options
 *
 * @public
 */
export declare interface CssParserOption {
    source: number;
    silent?: boolean;
}

/**
 * Get the angle value of the linear gradient
 *
 * @param value - target value
 *
 * @public
 */
export declare function getLinearGradientAngle(value: string): string;

/**
 * Get the color value of the linear gradient when it stops
 *
 * @param value - color
 *
 * @public
 */
export declare function getLinearGradientColorStop(value?: string): ColorObject | null;

declare type NeedToTyped = any;

/**
 * parse background image style attribute
 *
 * @param property - property name
 * @param value - property value
 *
 * @public
 */
export declare function parseBackgroundImage(property: string, value: NeedToTyped): [string, NeedToTyped];

/**
 * parse css code into AST tree
 *
 * @param css - css code
 * @param options - parse options
 *
 * @public
 */
export declare function parseCSS(css: string, options?: CssParserOption): CssNode;

/**
 * properties map
 *
 * @public
 */
export declare const PROPERTIES_MAP: {
    textDecoration: string;
    boxShadowOffset: string;
    boxShadowOffsetX: string;
    boxShadowOffsetY: string;
    boxShadowOpacity: string;
    boxShadowRadius: string;
    boxShadowSpread: string;
    boxShadowColor: string;
};

/**
 * @public
 */
export declare interface PropertiesMapType {
    textDecoration: 'string';
    boxShadowOffset: 'string';
    boxShadowOffsetX: 'string';
    boxShadowOffsetY: 'string';
    boxShadowOpacity: 'string';
    boxShadowRadius: 'string';
    boxShadowSpread: 'string';
    boxShadowColor: 'string';
}

/**
 * Convert css color value or string description to native supported color format
 *
 * @param color - color value or string description
 * @param options - options
 *
 * @public
 */
export declare function translateColor(color: string | number, options?: {
    platform?: string;
}): number;

export { }
